@@ -3,4 +3,4 @@
 from mitype.app import App
 
 if __name__ == "__main__":
-    OBJ = App()
+    App()
